@@ -346,6 +346,8 @@ var autocomplete = new AutoComplete(to.input[0], autoCompleteContainer);
 
 autocomplete.separator = ";";
 
+autocomplete.emailAutoComplete = false;
+
 autocomplete.enableDiv = function() {
     this.oDiv.style.width = this.oText.offsetWidth + "px";
     return AutoComplete.prototype.enableDiv.apply(this, arguments);
@@ -402,17 +404,25 @@ autocomplete.onAdditionalResponse = function(response, index) {
                 var groups = memberSet[user[0]];
                 for (var j = 2; j < user.length; j++) {
                     if (user[j]) {
-                        cache.add(format(
+                        cache.add(
+                            //#. Autocomplete entry for contacts
+                            //#. %1$s is the display name
+                            //#. %2$s is the field (type of phone number, e.g. Private or Mobile 2)
+                            //#. %3$s is the phone number
+                            format(_("%1$s, %2$s: %3$s"), user[1],
+                                phoneLabels[j - 2], user[j]),
+                            [user[j]],
                             //#. Autocomplete entry for group members
                             //#. %1$s is the display name
                             //#. %2$s is the field (type of phone number, e.g. Private or Mobile 2)
                             //#. %3$s is the phone number
                             //#. %4$s is the list of group names which contain the user
-                            ngettext("%1$s, %2$s: %3$s (group %4$s)",
-                                     "%1$s, %2$s: %3$s (groups %4$s)",
-                                     groups.length),
-                            user[1], phoneLabels[j - 2], user[j],
-                            groups.join(", ")), [user[j]]);
+                            format(ngettext("%1$s, %2$s: %3$s (group %4$s)",
+                                            "%1$s, %2$s: %3$s (groups %4$s)",
+                                            groups.length),
+                                   user[1], phoneLabels[j - 2], user[j],
+                                   groups.join(", "))
+                        );
                     }
                 }
             }
